#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abqiaabq_steady_state_lin_dyn_step_basic_vb import \
    ABQIAABQSteadyStateLinDynStepBasicVB


class ABQIAABQSteadyStateLinDynStepModalVB(ABQIAABQSteadyStateLinDynStepBasicVB):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAutomationItf.ABQStep
                |                         ABQAutomationItf.ABQIAABQSteadyStateLinDynStepBasicVB
                |                            ABQIAABQSteadyStateLinDynStepModalVB
                | 
                | Interface representing xxx.
                | 
                | Role: Components that implement ABQIAABQSteadyStateLinDynStepModal are
                | ...
                | 
                | Do not use the ABQIAABQSteadyStateLinDynStepModal interface for such and such
                | ClassReference, Class#MethodReference, #InternalMethod...
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abqiaabq_steady_state_lin_dyn_step_modal_vb = com_object

    @property
    def use_composite_damping_data(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UseCompositeDampingData() As boolean
                | 
                |     Sets or returns if the composite damping data is ued.
                | 
                |     Returns:
                |         A boolean specifying whether the composite damping data is ued.

        :rtype: bool
        """

        return self.abqiaabq_steady_state_lin_dyn_step_modal_vb.UseCompositeDampingData

    @use_composite_damping_data.setter
    def use_composite_damping_data(self, value: bool):
        """
        :param bool value:
        """

        self.abqiaabq_steady_state_lin_dyn_step_modal_vb.UseCompositeDampingData = value

    @property
    def use_direct_damping_data(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UseDirectDampingData() As boolean
                | 
                |     Sets or returns if the direct damping data is ued.
                | 
                |     Returns:
                |         A boolean specifying whether the direct damping data is ued.

        :rtype: bool
        """

        return self.abqiaabq_steady_state_lin_dyn_step_modal_vb.UseDirectDampingData

    @use_direct_damping_data.setter
    def use_direct_damping_data(self, value: bool):
        """
        :param bool value:
        """

        self.abqiaabq_steady_state_lin_dyn_step_modal_vb.UseDirectDampingData = value

    @property
    def use_rayleigh_damping_data(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UseRayleighDampingData() As boolean
                | 
                |     Sets or returns if the rayleigh damping data is ued.
                | 
                |     Returns:
                |         A boolean specifying whether the rayleigh damping data is ued.

        :rtype: bool
        """

        return self.abqiaabq_steady_state_lin_dyn_step_modal_vb.UseRayleighDampingData

    @use_rayleigh_damping_data.setter
    def use_rayleigh_damping_data(self, value: bool):
        """
        :param bool value:
        """

        self.abqiaabq_steady_state_lin_dyn_step_modal_vb.UseRayleighDampingData = value

    @property
    def use_structural_damping_data(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UseStructuralDampingData() As boolean
                | 
                |     Sets or returns if the structural damping data is ued.
                | 
                |     Returns:
                |         A boolean specifying whether the structural damping data is ued.

        :rtype: bool
        """

        return self.abqiaabq_steady_state_lin_dyn_step_modal_vb.UseStructuralDampingData

    @use_structural_damping_data.setter
    def use_structural_damping_data(self, value: bool):
        """
        :param bool value:
        """

        self.abqiaabq_steady_state_lin_dyn_step_modal_vb.UseStructuralDampingData = value

    def add_composite_damping_data_table(self, i_column1: tuple, i_column2: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddCompositeDampingDataTable(CATSafeArrayVariant
                | iColumn1,
                | CATSafeArrayVariant iColumn2)
                | 
                |     Adds a composite damping data over ranges of Modes or Frequencies The
                |     number of values in both the parameters must match. If either list contains
                |     extra values, the extra values are discarded. Valid only for damping over
                |     ranges of Modes.
                | 
                |     Parameters:
                | 
                |         iColumn1
                |             The list of start modes.
                |         iColumn2
                |             The list of end modes.

        :param tuple i_column1:
        :param tuple i_column2:
        :rtype: None
        """
        return self.abqiaabq_steady_state_lin_dyn_step_modal_vb.AddCompositeDampingDataTable(i_column1, i_column2)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_composite_damping_data_table'
        # # vba_code = """
        # # Public Function add_composite_damping_data_table(abqiaabq_steady_state_lin_dyn_step_modal_vb)
        # #     Dim iColumn1 (2)
        # #     abqiaabq_steady_state_lin_dyn_step_modal_vb.AddCompositeDampingDataTable iColumn1
        # #     add_composite_damping_data_table = iColumn1
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_direct_damping_data_table(
            self,
            i_damping_range: str,
            i_column1: tuple,
            i_column2: tuple,
            i_column3: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddDirectDampingDataTable(CATBSTR iDampingRange,
                | CATSafeArrayVariant iColumn1,
                | CATSafeArrayVariant iColumn2,
                | CATSafeArrayVariant iColumn3)
                | 
                |     Adds a direct damping data over ranges of Modes or Frequencies The number
                |     of values in all the three of the parameters must match. If either list
                |     contains extra values, the extra values are discarded.
                | 
                |     Parameters:
                | 
                |         iDampingRange
                |             The range over which damping is defined.
                | 
                |               
                |             Legal values:
                |              MODES.
                |              FREQUENCIES.
                |              
                | 
                |         iColumn1
                |             For daming range = MODES - The list of start modes.
                |             For daming range = FREQUENCIES - The list of frequencies.
                |         iColumn2
                |             For daming range = MODES - The list of end modes.
                |             For daming range = FREQUENCIES - The list of critical damping fraction.
                |         iColumn3
                |             For daming range = MODES - The list of critical damping fraction.
                |             For daming range = FREQUENCIES - iColumn3 will be ignored if the damping range is FREQUENCIES.

        :param str i_damping_range:
        :param tuple i_column1:
        :param tuple i_column2:
        :param tuple i_column3:
        :rtype: None
        """
        return self.abqiaabq_steady_state_lin_dyn_step_modal_vb.AddDirectDampingDataTable(
            i_damping_range,
            i_column1,
            i_column2,
            i_column3
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_direct_damping_data_table'
        # # vba_code = """
        # # Public Function add_direct_damping_data_table(abqiaabq_steady_state_lin_dyn_step_modal_vb)
        # #     Dim iDampingRange (2)
        # #     abqiaabq_steady_state_lin_dyn_step_modal_vb.AddDirectDampingDataTable iDampingRange
        # #     add_direct_damping_data_table = iDampingRange
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_rayleigh_damping_data_table(
            self,
            i_damping_range: str,
            i_column1:
            tuple,
            i_column2: tuple,
            i_column3: tuple,
            i_column4: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddRayleighDampingDataTable(CATBSTR iDampingRange,
                | CATSafeArrayVariant iColumn1,
                | CATSafeArrayVariant iColumn2,
                | CATSafeArrayVariant iColumn3,
                | CATSafeArrayVariant iColumn4)
                | 
                |     Adds a rayleigh damping data over ranges of Modes or Frequencies The number
                |     of values in all the four of the parameters must match. If either list contains
                |     extra values, the extra values are discarded.
                | 
                |     Parameters:
                | 
                |         iDampingRange
                |             The range over which damping is defined.
                | 
                |               
                |             Legal values:
                |              MODES.
                |              FREQUENCIES.
                |              
                | 
                |         iColumn1
                |             For daming range = MODES - The list of start modes.
                |             For daming range = FREQUENCIES - The list of frequencies.
                |         iColumn2
                |             For daming range = MODES - The list of end modes.
                |             For daming range = FREQUENCIES - The list of alpha coefficients.
                |         iColumn3
                |             For daming range = MODES - The list of alpha coefficients.
                |             For daming range = FREQUENCIES - The list of beta coefficients.
                |         iColumn4
                |             For daming range = MODES - The list of beta coefficients.
                |             For daming range = FREQUENCIES - iColumn4 will be ignored if the damping range is FREQUENCIES.

        :param str i_damping_range:
        :param tuple i_column1:
        :param tuple i_column2:
        :param tuple i_column3:
        :param tuple i_column4:
        :rtype: None
        """
        return self.abqiaabq_steady_state_lin_dyn_step_modal_vb.AddRayleighDampingDataTable(
            i_damping_range,
            i_column1,
            i_column2,
            i_column3,
            i_column4
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_rayleigh_damping_data_table'
        # # vba_code = """
        # # Public Function add_rayleigh_damping_data_table(abqiaabq_steady_state_lin_dyn_step_modal_vb)
        # #     Dim iDampingRange (2)
        # #     abqiaabq_steady_state_lin_dyn_step_modal_vb.AddRayleighDampingDataTable iDampingRange
        # #     add_rayleigh_damping_data_table = iDampingRange
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_structural_damping_data_table(
            self,
            i_damping_range: str,
            i_column1: tuple,
            i_column2: tuple,
            i_column3: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddStructuralDampingDataTable(CATBSTR iDampingRange,
                | CATSafeArrayVariant iColumn1,
                | CATSafeArrayVariant iColumn2,
                | CATSafeArrayVariant iColumn3)
                | 
                |     Adds a structural damping data over ranges of Modes or Frequencies The
                |     number of values in all the three of the parameters must match. If either list
                |     contains extra values, the extra values are discarded.
                | 
                |     Parameters:
                | 
                |         iDampingRange
                |             The range over which damping is defined.
                |
                |             Legal values:
                |              MODES.
                |              FREQUENCIES.
                |         iColumn1
                |             For daming range = MODES - The list of start modes.
                |             For daming range = FREQUENCIES - The list of frequencies.
                |         iColumn2
                |             For daming range = MODES - The list of end modes.
                |             For daming range = FREQUENCIES - The list of damping constant.
                |         iColumn3
                |             For daming range = MODES - The list of damping constant.
                |             For daming range = FREQUENCIES - iColumn3 will be ignored if the damping range is FREQUENCIES.

        :param str i_damping_range:
        :param tuple i_column1:
        :param tuple i_column2:
        :param tuple i_column3:
        :rtype: None
        """
        return self.abqiaabq_steady_state_lin_dyn_step_modal_vb.AddStructuralDampingDataTable(
            i_damping_range,
            i_column1,
            i_column2,
            i_column3
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_structural_damping_data_table'
        # # vba_code = """
        # # Public Function add_structural_damping_data_table(abqiaabq_steady_state_lin_dyn_step_modal_vb)
        # #     Dim iDampingRange (2)
        # #     abqiaabq_steady_state_lin_dyn_step_modal_vb.AddStructuralDampingDataTable iDampingRange
        # #     add_structural_damping_data_table = iDampingRange
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ABQIAABQSteadyStateLinDynStepModalVB(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_app_connectable import SchAppConnectable
from pycatia.cat_sch_platform_interfaces.sch_app_connector import SchAppConnector
from pycatia.cat_sch_platform_interfaces.sch_list_of_bst_rs import SchListOfBSTRs
from pycatia.cat_sch_platform_interfaces.sch_list_of_objects import SchListOfObjects
from pycatia.system_interfaces.any_object import AnyObject


class SchGRR(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchGRR
                | 
                | Manage the graphical representation of a schematic object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_grr = com_object

    def get_grr_name(self, o_grr_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetGRRName(CATBSTR oGRRName)
                | 
                |     Get current name of the GRR.
                | 
                |     Parameters:
                | 
                |         oGRRName
                |             The name of this GRR. A component can be associated with more than
                |             one GRRs. Each GRR is identified by a specific name. Valid names are specified
                |             by the application when building the component. Every component should have a
                |             GRR named "Primary". The GRR by this name is used in the catalog.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchGRR
                |          Dim strVar1 As String
                |           ...
                |          objThisIntf.GetGRRNamestrVar1

        :param str o_grr_name:
        :rtype: None
        """
        return self.sch_grr.GetGRRName(o_grr_name)

    def get_sch_cntr_owners(self, o_cntr_owner: SchAppConnector, o_grr_owner: 'SchGRR') -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetSchCntrOwners(SchAppConnector oCntrOwner,
                | SchGRR oGRROwner)
                | 
                |     Get the schematic objects that own this connector graphic
                |     representation.
                | 
                |     Parameters:
                | 
                |         oCntrOwner.
                |             A schematic connector that owns this connector graphic
                |             representation. 
                |         oGRROwner
                |             A component or route graphic representation that owns this
                |             connector graphic representation. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchGRR
                |          Dim objArg1 As SchAppConnector
                |          Dim objArg2 As SchGRR
                |           ...
                |          objThisIntf.GetSchCntrOwnersobjArg1,objArg2

        :param SchAppConnector o_cntr_owner:
        :param SchGRR o_grr_owner:
        :rtype: None
        """
        return self.sch_grr.GetSchCntrOwners(o_cntr_owner.com_object, o_grr_owner.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_sch_cntr_owners'
        # # vba_code = """
        # # Public Function get_sch_cntr_owners(sch_grr)
        # #     Dim oCntrOwner (2)
        # #     sch_grr.GetSchCntrOwners oCntrOwner
        # #     get_sch_cntr_owners = oCntrOwner
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_sch_obj_owner(self) -> SchAppConnectable:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSchObjOwner() As SchAppConnectable
                | 
                |     Get the schematic object that owns this graphic
                |     representation.
                | 
                |     Parameters:
                | 
                |         oGRROwner
                |             A schematic object that owns this graphic representation.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchGRR
                |          Dim objArg1 As SchAppConnectable
                |           ...
                |          Set objArg1 = objThisIntf.GetSchObjOwner

        :rtype: SchAppConnectable
        """
        return SchAppConnectable(self.sch_grr.GetSchObjOwner())

    def list_connected_gr_rs(
            self,
            i_grr_owner: SchAppConnectable,
            i_l_cntble_class_filter: SchListOfBSTRs,
            o_l_cntble_gr_rs: SchListOfObjects,
            o_l_cntbles: SchListOfObjects,
            o_l_cntrs_on_this_obj: SchListOfObjects,
            o_l_cntrs_on_connected: SchListOfObjects
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ListConnectedGRRs(SchAppConnectable iGRROwner,
                | SchListOfBSTRs iLCntbleClassFilter,
                | SchListOfObjects oLCntbleGRRs,
                | SchListOfObjects oLCntbles,
                | SchListOfObjects oLCntrsOnThisObj,
                | SchListOfObjects oLCntrsOnConnected)
                | 
                |     Get a list of graphical objects that connects to this graphic
                |     representation.
                | 
                |     Parameters:
                | 
                |         iGRROwner
                |             A CATISchAppConnectable that owns this graphic representation. In
                |             the case of GRRCntr (this object), iGRROwner is the owner of the owner of this
                |             graphic. 
                |         oLCntrClassFilter
                |             A list of all the class types for filtering the output application
                |             objects list. 
                |         oLCntbleGRRs
                |             A list of GRRs connected to this GRR. (members are CATISchGRR
                |             interface pointers). 
                |         oLCntbles
                |             A list of application objects connected to this object. (members
                |             are CATISchAppConnectable interface pointers). 
                |         oLCntrsOnThisObj
                |             A list of connectors on this object through which the connection is
                |             made. (members are CATISchAppConnector interface pointers).
                |             
                |         oLCntrsOnConnected
                |             A list of connectors on the connected objects through which the
                |             connection is made. (members are CATISchAppConnector interface pointers).
                |             Members in this list corresponds to those in oLCntrsOnThisObj in making the
                |             corresponding connections. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchGRR
                |          Dim objArg1 As SchAppConnectable
                |          Dim objArg2 As SchListOfBSTRs
                |          Dim objArg3 As SchListOfObjects
                |          Dim objArg4 As SchListOfObjects
                |          Dim objArg5 As SchListOfObjects
                |          Dim objArg6 As SchListOfObjects
                |           ...
                |          objThisIntf.ListConnectedGRRsobjArg1,objArg2,objArg3,objArg4,objArg5,objArg6

        :param SchAppConnectable i_grr_owner:
        :param SchListOfBSTRs i_l_cntble_class_filter:
        :param SchListOfObjects o_l_cntble_gr_rs:
        :param SchListOfObjects o_l_cntbles:
        :param SchListOfObjects o_l_cntrs_on_this_obj:
        :param SchListOfObjects o_l_cntrs_on_connected:
        :rtype: None
        """
        return self.sch_grr.ListConnectedGRRs(
            i_grr_owner.com_object,
            i_l_cntble_class_filter.com_object,
            o_l_cntble_gr_rs.com_object,
            o_l_cntbles.com_object,
            o_l_cntrs_on_this_obj.com_object,
            o_l_cntrs_on_connected.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'list_connected_gr_rs'
        # # vba_code = """
        # # Public Function list_connected_gr_rs(sch_grr)
        # #     Dim iGRROwner (2)
        # #     sch_grr.ListConnectedGRRs iGRROwner
        # #     list_connected_gr_rs = iGRROwner
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_grr_name(self, i_grr_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetGRRName(CATBSTR iGRRName)
                | 
                |     Set current name of the GRR.
                | 
                |     Parameters:
                | 
                |         iGRRName
                |             The name of this GRR to be set. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchGRR
                |          Dim strVar1 As String
                |           ...
                |          objThisIntf.SetGRRNamestrVar1

        :param str i_grr_name:
        :rtype: None
        """
        return self.sch_grr.SetGRRName(i_grr_name)

    def __repr__(self):
        return f'SchGRR(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_load import ABQLoad
from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.axis_system import AxisSystem
from pycatia.product_structure_interfaces.product import Product
from pycatia.product_structure_interfaces.publication import Publication


class ABQConcentratedForce(ABQLoad):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAutomationItf.ABQLoad
                |                         ABQConcentratedForce
                | 
                | Represents an Abaqus concentrated force object
                | (ABQConcentratedForce).
                | Role: Access an Abaqus concentrated force object or determine its
                | properties.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_concentrated_force = com_object

    @property
    def apply_user_subroutine(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ApplyUserSubroutine() As boolean
                | 
                |     Sets or returns the user subroutine flag.
                | 
                |     Returns:
                |         A boolean specifying whether a user subroutine will be
                |         applied.

        :rtype: bool
        """

        return self.abq_concentrated_force.ApplyUserSubroutine

    @apply_user_subroutine.setter
    def apply_user_subroutine(self, value: bool):
        """
        :param bool value:
        """

        self.abq_concentrated_force.ApplyUserSubroutine = value

    @property
    def follow_nodal_rotation(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FollowNodalRotation() As boolean
                | 
                |     Sets or returns the follow nodal rotation flag.

        :rtype: bool
        """

        return self.abq_concentrated_force.FollowNodalRotation

    @follow_nodal_rotation.setter
    def follow_nodal_rotation(self, value: bool):
        """
        :param bool value:
        """

        self.abq_concentrated_force.FollowNodalRotation = value

    @property
    def load_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property LoadType() As ABQConcForceLoad_Type
                | 
                |     Sets or returns the load type whether Point Load, Distributed Load or Load
                |     Density.
                | 
                |     Returns:
                |         The load type.
                | 
                |         Legal values:
                | 
                |         POINTLOAD
                |         DISTRIBUTEDLOAD
                |         LOADDENSITY

        :return: enum abq_conc_force_load_type
        :rtype: int
        """

        return self.abq_concentrated_force.LoadType

    @load_type.setter
    def load_type(self, value: int):
        """
        :param int value: enum abq_conc_force_load_type
        """

        self.abq_concentrated_force.LoadType = value

    @property
    def uselocal_csys(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UselocalCsys() As boolean
                | 
                |     Sets or returns a boolean indicating whether local coordinate system is
                |     used in Conc force
                | 
                |     Returns:
                |         boolean specifying whether local csys is active.

        :rtype: bool
        """

        return self.abq_concentrated_force.UselocalCsys

    @uselocal_csys.setter
    def uselocal_csys(self, value: bool):
        """
        :param bool value:
        """

        self.abq_concentrated_force.UselocalCsys = value

    @property
    def cf1(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property cf1() As double
                | 
                |     Sets or returns the concentrated force component in the
                |     1-direction.
                | 
                |     Returns:
                |         The concentrated force component in the 1-direction.

        :rtype: float
        """

        return self.abq_concentrated_force.cf1

    @cf1.setter
    def cf1(self, value: float):
        """
        :param float value:
        """

        self.abq_concentrated_force.cf1 = value

    @property
    def cf2(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property cf2() As double
                | 
                |     Sets or returns the concentrated force component in the
                |     2-direction.
                | 
                |     Returns:
                |         The concentrated force component in the 2-direction.

        :rtype: float
        """

        return self.abq_concentrated_force.cf2

    @cf2.setter
    def cf2(self, value: float):
        """
        :param float value:
        """

        self.abq_concentrated_force.cf2 = value

    @property
    def cf3(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property cf3() As double
                | 
                |     Sets or returns the concentrated force component in the
                |     3-direction.
                | 
                |     Returns:
                |         The concentrated force component in the 3-direction.

        :rtype: float
        """

        return self.abq_concentrated_force.cf3

    @cf3.setter
    def cf3(self, value: float):
        """
        :param float value:
        """

        self.abq_concentrated_force.cf3 = value

    @property
    def cm1(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property cm1() As double
                | 
                |     Sets or returns the concentrated moment component in the
                |     1-direction.
                | 
                |     Returns:
                |         The concentrated moment component in the 1-direction.

        :rtype: float
        """

        return self.abq_concentrated_force.cm1

    @cm1.setter
    def cm1(self, value: float):
        """
        :param float value:
        """

        self.abq_concentrated_force.cm1 = value

    @property
    def cm2(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property cm2() As double
                | 
                |     Sets or returns the concentrated moment component in the
                |     2-direction.
                | 
                |     Returns:
                |         The concentrated moment component in the 2-direction.

        :rtype: float
        """

        return self.abq_concentrated_force.cm2

    @cm2.setter
    def cm2(self, value: float):
        """
        :param float value:
        """

        self.abq_concentrated_force.cm2 = value

    @property
    def cm3(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property cm3() As double
                | 
                |     Sets or returns the concentrated moment component in the
                |     3-direction.
                | 
                |     Returns:
                |         The concentrated moment component in the 3-direction.

        :rtype: float
        """

        return self.abq_concentrated_force.cm3

    @cm3.setter
    def cm3(self, value: float):
        """
        :param float value:
        """

        self.abq_concentrated_force.cm3 = value

    @property
    def local_csys(self) -> AxisSystem:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property localCsys() As AxisSystem
                | 
                |     Sets or returns the local coordinate system of the concentrated
                |     force.
                | 
                |     Returns:
                |         The local coordinate system.

        :rtype: AxisSystem
        """

        return AxisSystem(self.abq_concentrated_force.localCsys)

    @local_csys.setter
    def local_csys(self, value: AxisSystem):
        """
        :param AxisSystem value:
        """

        self.abq_concentrated_force.localCsys = value

    def get_handler(self, o_product: Reference, o_ref: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetHandler(Reference oProduct,
                | Reference oRef)
                | 
                |     Returns the handler for the distributed load.
                | 
                |     Parameters:
                | 
                |         oProduct
                |             The product for the handler. 
                |         oRef
                |             The reference to the handler.

        :param Reference o_product:
        :param Reference o_ref:
        :rtype: None
        """
        return self.abq_concentrated_force.GetHandler(o_product.com_object, o_ref.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_handler'
        # # vba_code = """
        # # Public Function get_handler(abq_concentrated_force)
        # #     Dim oProduct (2)
        # #     abq_concentrated_force.GetHandler oProduct
        # #     get_handler = oProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_local_csys_from_publication(self, o_product: Product, o_pub_axis_system: AxisSystem) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetLocalCsysFromPublication(Product oProduct,
                | AxisSystem oPubAxisSystem)
                | 
                |     Gets the published local coordinate system of the concentrated
                |     force.
                | 
                |     Parameters:
                | 
                |         oProduct
                |             The CATIA Product specifying the local coordinate system
                |             publication.
                |         oPubAxisSystem
                |             The CATIA Axis system.
                | 
                |             Refer: CATIAAxisSystem

        :param Product o_product:
        :param AxisSystem o_pub_axis_system:
        :rtype: None
        """
        return self.abq_concentrated_force.GetLocalCsysFromPublication(o_product.com_object,
                                                                       o_pub_axis_system.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_local_csys_from_publication'
        # # vba_code = """
        # # Public Function get_local_csys_from_publication(abq_concentrated_force)
        # #     Dim oProduct (2)
        # #     abq_concentrated_force.GetLocalCsysFromPublication oProduct
        # #     get_local_csys_from_publication = oProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_use_coordinate_system_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetUseCoordinateSystemType() As ABQLocalCsysType
                |
                |     Get the user coordinate system type.
                |
                |     Parameters:
                |
                |         oCsystemType
                |             e.g. ABQ_CARTESIAN, ABQ_CYLINDRICAL, ABQ_SPHERICAL,
                |             ABQ_DEFAULTAXIS

        :rtype: enum abq_local_csys_type
        :rtype: int
        """
        return self.abq_concentrated_force.GetUseCoordinateSystemType()

    def set_handler(self, i_product: Reference, i_ref: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetHandler(Reference iProduct,
                | Reference iRef)
                |
                |     Sets the handler for the distributed load. Any previously set handler will
                |     be replaced with this new value.
                |
                |     Parameters:
                |
                |         iProduct
                |             The product for the handler.
                |         iRef
                |             The reference to the handler.

        :param Reference i_product:
        :param Reference i_ref:
        :rtype: None
        """
        return self.abq_concentrated_force.SetHandler(i_product.com_object, i_ref.com_object)
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_handler'
        # # vba_code = """
        # # Public Function set_handler(abq_concentrated_force)
        # #     Dim iProduct (2)
        # #     abq_concentrated_force.SetHandler iProduct
        # #     set_handler = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_local_csys_from_publication(self, i_product: Product, i_pub_axis_system: Publication) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetLocalCsysFromPublication(Product iProduct,
                | Publication iPubAxisSystem)
                |
                |     Sets the published local coordinate system of the concentrated
                |     force.
                |
                |     Returns:
                |         Fails if the publication is not an axis system.
                |     Parameters:
                |
                |         iProduct
                |             The CATIA Product specifying the local coordinate system
                |             publication.
                |         iPublication
                |             The CATIA Publication on the axis system.
                |
                |             Refer: CATIAPublication

        :param Product i_product:
        :param Publication i_pub_axis_system:
        :rtype: None
        """
        return self.abq_concentrated_force.SetLocalCsysFromPublication(i_product.com_object,
                                                                       i_pub_axis_system.com_object)
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_local_csys_from_publication'
        # # vba_code = """
        # # Public Function set_local_csys_from_publication(abq_concentrated_force)
        # #     Dim iProduct (2)
        # #     abq_concentrated_force.SetLocalCsysFromPublication iProduct
        # #     set_local_csys_from_publication = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_use_coordinate_system_type(self, i_csystem_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetUseCoordinateSystemType(ABQLocalCsysType
                | iCsystemType)
                |
                |     set the user coordinate system type.
                |
                |     Parameters:
                |
                |         iCsystemType
                |             e.g. ABQ_CARTESIAN, ABQ_CYLINDRICAL, ABQ_SPHERICAL,
                |             ABQ_DEFAULTAXIS

        :param int i_csystem_type: enum abq_local_csys_type
        :rtype: None
        """
        return self.abq_concentrated_force.SetUseCoordinateSystemType(i_csystem_type)

    def __repr__(self):
        return f'ABQConcentratedForce(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.plane import Plane
from pycatia.in_interfaces.reference import Reference


class HybridShapePlane2Lines(Plane):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         CATGSMIDLItf.Plane
                |                             HybridShapePlane2Lines
                | 
                | plane defined by two lines.
                | Role: Allows to access data of the plane feature passing though two
                | lines.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_plane2_lines = com_object

    @property
    def first(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property First() As Reference
                | 
                |     Role: Get the first line.
                | 
                |     Parameters:
                | 
                |         oLine1
                |             first line. 
                | 
                |     See also:
                |         Reference 
                |     Returns:
                |         HRESULT S_OK if Ok E_FAIL else return error code for C++
                |         Implementations 
                |     See also:
                |         HybridShapeFactory

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_plane2_lines.First)

    @first.setter
    def first(self, reference_line: Reference):
        """
        :param Reference reference_line:
        """

        self.hybrid_shape_plane2_lines.First = reference_line.com_object

    @property
    def forbid_non_coplanar_lines(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ForbidNonCoplanarLines(boolean iCoplanarLines)
                | 
                |     if ForbidNonCoplanarLines = TRUE, both lines have to be on the same plane.
                |     if ForbidNonCoplanarLines = FALSE, both lines can be non coplanar.

        :rtype: bool
        """

        return self.hybrid_shape_plane2_lines.ForbidNonCoplanarLines()

    @forbid_non_coplanar_lines.setter
    def forbid_non_coplanar_lines(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_plane2_lines.ForbidNonCoplanarLines = value

    @property
    def second(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Second() As Reference
                | 
                |     Role: Get the second line.
                | 
                |     Parameters:
                | 
                |         oLine2
                |             second line. 
                | 
                |     See also:
                |         Reference 
                |     Returns:
                |         HRESULT S_OK if Ok E_FAIL else return error code for C++
                |         Implementations 
                |     See also:
                |         HybridShapeFactory

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_plane2_lines.Second)

    @second.setter
    def second(self, reference_line: Reference):
        """
        :param Reference reference_line:
        """

        self.hybrid_shape_plane2_lines.Second = reference_line.com_object

    def __repr__(self):
        return f'HybridShapePlane2Lines(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_app_route import SchAppRoute
from pycatia.in_interfaces.document import Document
from pycatia.system_interfaces.any_object import AnyObject


class SchAppObjectFactory2(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchAppObjectFactory2
                | 
                | Application factory to create application objects.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_app_object_factory2 = com_object

    def app_create_comp_ref(self, i_app_comp_class_type: str, i_doc: Document, o_app_comp: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppCreateCompRef(CATBSTR iAppCompClassType,
                | Document iDoc,
                | AnyObject oAppComp)
                | 
                |     Create an Application Component reference.
                | 
                |     Parameters:
                | 
                |         iAppCompClassType
                |             Class type of the Application Component reference.
                |             
                |         iDoc
                |             Pointer to a document to create the object in. If NULL, the
                |             document associated with the current Editor will be used.
                |             
                |         oAppComp
                |             The new Application Component object created (CATISchAppComponent
                |             interface pointer). 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppObjectFactory2
                |          Dim strVar1 As String
                |          Dim objArg2 As Document
                |          Dim objArg3 As AnyObject
                |           ...
                |          objThisIntf.AppCreateCompRefstrVar1,objArg2,objArg3

        :param str i_app_comp_class_type:
        :param Document i_doc:
        :param AnyObject o_app_comp:
        :rtype: None
        """
        return self.sch_app_object_factory2.AppCreateCompRef(
            i_app_comp_class_type,
            i_doc.com_object,
            o_app_comp.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_create_comp_ref'
        # # vba_code = """
        # # Public Function app_create_comp_ref(sch_app_object_factory2)
        # #     Dim iAppCompClassType (2)
        # #     sch_app_object_factory2.AppCreateCompRef iAppCompClassType
        # #     app_create_comp_ref = iAppCompClassType
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_create_connection(self, i_app_cntn_class_type: str, i_doc: Document, o_app_connection: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppCreateConnection(CATBSTR iAppCntnClassType,
                | Document iDoc,
                | AnyObject oAppConnection)
                | 
                |     Create an Application Connection object.
                | 
                |     Parameters:
                | 
                |         iAppCntnClassType
                |             Class type of the Application Connection object. 
                |         iDoc
                |             Pointer to a document to create the object in. If NULL, the
                |             document associated with the current Editor will be used.
                |             
                |         oAppConnection
                |             The new Application Connection object created (CATISchAppConnection
                |             interface pointer). 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppObjectFactory2
                |          Dim strVar1 As String
                |          Dim objArg2 As Document
                |          Dim objArg3 As AnyObject
                |           ...
                |         
                |         objThisIntf.AppCreateConnectionstrVar1,objArg2,objArg3

        :param str i_app_cntn_class_type:
        :param Document i_doc:
        :param AnyObject o_app_connection:
        :rtype: None
        """
        return self.sch_app_object_factory2.AppCreateConnection(
            i_app_cntn_class_type,
            i_doc.com_object,
            o_app_connection.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_create_connection'
        # # vba_code = """
        # # Public Function app_create_connection(sch_app_object_factory2)
        # #     Dim iAppCntnClassType (2)
        # #     sch_app_object_factory2.AppCreateConnection iAppCntnClassType
        # #     app_create_connection = iAppCntnClassType
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_create_group(self, i_app_group_class_type: str, i_doc: Document, o_app_group: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppCreateGroup(CATBSTR iAppGroupClassType,
                | Document iDoc,
                | AnyObject oAppGroup)
                | 
                |     Create an Application Group object.
                | 
                |     Parameters:
                | 
                |         iAppGroupClassType
                |             Class type of the Application Group object. 
                |         iDoc
                |             Pointer to a document to create the object in. If NULL, the
                |             document associated with the current Editor will be used.
                |             
                |         oAppGroup
                |             The new Application Group object created (CATISchAppGroup interface
                |             pointer). 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppObjectFactory2
                |          Dim strVar1 As String
                |          Dim objArg2 As Document
                |          Dim objArg3 As AnyObject
                |           ...
                |          objThisIntf.AppCreateGroupstrVar1,objArg2,objArg3

        :param str i_app_group_class_type:
        :param Document i_doc:
        :param AnyObject o_app_group:
        :rtype: None
        """
        return self.sch_app_object_factory2.AppCreateGroup(
            i_app_group_class_type,
            i_doc.com_object,
            o_app_group.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_create_group'
        # # vba_code = """
        # # Public Function app_create_group(sch_app_object_factory2)
        # #     Dim iAppGroupClassType (2)
        # #     sch_app_object_factory2.AppCreateGroup iAppGroupClassType
        # #     app_create_group = iAppGroupClassType
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_create_route(
            self,
            i_app_route_class_type: str,
            i_doc: Document,
            i_log_line_id: str,
            o_app_route: AnyObject
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppCreateRoute(CATBSTR iAppRouteClassType,
                | Document iDoc,
                | CATBSTR iLogLineID,
                | AnyObject oAppRoute)
                | 
                |     Create an Application Route object.
                | 
                |     Parameters:
                | 
                |         iAppRouteClassType
                |             Class type of the Application Route object. 
                |         iDoc
                |             Pointer to a document to create the object in. If NULL, the
                |             document associated with the current Editor will be used.
                |             
                |         iLogLineID
                |             The logical line ID that will contain the new route. This is an
                |             optional input. If could be NULL. 
                |         oAppRoute
                |             The new Application Route object created (CATISchAppRoute interface
                |             pointer). 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppObjectFactory2
                |          Dim strVar1 As String
                |          Dim objArg2 As Document
                |          Dim strVar3 As String
                |          Dim objArg4 As AnyObject
                |           ...
                |          objThisIntf.AppCreateRoutestrVar1,objArg2,strVar3,objArg4

        :param str i_app_route_class_type:
        :param Document i_doc:
        :param str i_log_line_id:
        :param AnyObject o_app_route:
        :rtype: None
        """
        return self.sch_app_object_factory2.AppCreateRoute(
            i_app_route_class_type,
            i_doc.com_object,
            i_log_line_id,
            o_app_route.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_create_route'
        # # vba_code = """
        # # Public Function app_create_route(sch_app_object_factory2)
        # #     Dim iAppRouteClassType (2)
        # #     sch_app_object_factory2.AppCreateRoute iAppRouteClassType
        # #     app_create_route = iAppRouteClassType
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_create_route_from_ref(
            self,
            i_route_reference: SchAppRoute,
            i_doc: Document,
            i_log_line_id: str,
            o_app_route: AnyObject
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppCreateRouteFromRef(SchAppRoute iRouteReference,
                | Document iDoc,
                | CATBSTR iLogLineID,
                | AnyObject oAppRoute)
                | 
                |     Create an Application Route object with a specific
                |     reference.
                | 
                |     Parameters:
                | 
                |         iAppRouteRef
                |             Route reference to creaet the output route from 
                |         iDoc
                |             Pointer to a document to create the object in. If NULL, the
                |             document associated with the current Editor will be used.
                |             
                |         iLogLineID
                |             The logical line ID that will contain the new route. This is an
                |             optional input. If could be NULL. 
                |         oAppRoute
                |             The new Application Route object created (CATISchAppRoute interface
                |             pointer). 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchAppObjectFactory2
                |          Dim objArg1 As SchAppRoute
                |          Dim objArg2 As Document
                |          Dim strVar3 As String
                |          Dim objArg4 As AnyObject
                |           ...
                |          objThisIntf.AppCreateRouteFromRefobjArg1,objArg2,strVar3,objArg4

        :param SchAppRoute i_route_reference:
        :param Document i_doc:
        :param str i_log_line_id:
        :param AnyObject o_app_route:
        :rtype: None
        """
        return self.sch_app_object_factory2.AppCreateRouteFromRef(
            i_route_reference.com_object,
            i_doc.com_object,
            i_log_line_id,
            o_app_route.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_create_route_from_ref'
        # # vba_code = """
        # # Public Function app_create_route_from_ref(sch_app_object_factory2)
        # #     Dim iRouteReference (2)
        # #     sch_app_object_factory2.AppCreateRouteFromRef iRouteReference
        # #     app_create_route_from_ref = iRouteReference
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_create_route_with_info(
            self,
            i_app_route_class_type: str,
            i_app_info: AnyObject,
            o_app_route: AnyObject
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppCreateRouteWithInfo(CATBSTR iAppRouteClassType,
                | AnyObject iAppInfo,
                | AnyObject oAppRoute)
                | 
                |     Create an Application Route object with application
                |     information.
                | 
                |     Parameters:
                | 
                |         iAppRouteClassType
                |             Class type of the Application Route object. 
                |         iAppInfo
                |             Application data pointer 
                |         oAppRoute
                |             The new Application Route object created (CATISchAppRoute interface
                |             pointer). 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppObjectFactory2
                |          Dim strVar1 As String
                |          Dim objArg2 As AnyObject
                |          Dim objArg3 As AnyObject
                |           ...
                |          objThisIntf.AppCreateRouteWithInfostrVar1,objArg2,objArg3

        :param str i_app_route_class_type:
        :param AnyObject i_app_info:
        :param AnyObject o_app_route:
        :rtype: None
        """
        return self.sch_app_object_factory2.AppCreateRouteWithInfo(
            i_app_route_class_type,
            i_app_info.com_object,
            o_app_route.com_object
        )

    def app_create_zone(
            self,
            i_app_zone_class_type: str,
            i_doc: Document,
            o_app_zone: AnyObject
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppCreateZone(CATBSTR iAppZoneClassType,
                | Document iDoc,
                | AnyObject oAppZone)
                | 
                |     Create an Application Zone object.
                | 
                |     Parameters:
                | 
                |         iAppZoneClassType
                |             Class type of the Application Zone object. 
                |         iDoc
                |             Pointer to a document to create the object in. If NULL, the
                |             document associated with the current Editor will be used.
                |             
                |         oAppZone
                |             The new Application Zone object created (CATISchAppZone interface
                |             pointer). 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchAppObjectFactory2
                |          Dim strVar1 As String
                |          Dim objArg2 As Document
                |          Dim objArg3 As AnyObject
                |           ...
                |          objThisIntf.AppCreateZonestrVar1,objArg2,objArg3

        :param str i_app_zone_class_type:
        :param Document i_doc:
        :param AnyObject o_app_zone:
        :rtype: None
        """
        return self.sch_app_object_factory2.AppCreateZone(
            i_app_zone_class_type,
            i_doc.com_object,
            o_app_zone.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_create_zone'
        # # vba_code = """
        # # Public Function app_create_zone(sch_app_object_factory2)
        # #     Dim iAppZoneClassType (2)
        # #     sch_app_object_factory2.AppCreateZone iAppZoneClassType
        # #     app_create_zone = iAppZoneClassType
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchAppObjectFactory2(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.exception_handling.exceptions import CATIAApplicationException
from pycatia.system_interfaces.any_object import AnyObject


class RenderingMaterial(AnyObject):
    """
    .. note::
        :class: toggle

        CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

            | System.IUnknown
            |     System.IDispatch
            |         System.CATBaseUnknown
            |             System.CATBaseDispatch
            |                 System.AnyObject
            |                     RenderingMaterial
            |
            | Represents an RenderingMaterial object.
            | This object is used to manage the Rendering properties of a
            | material.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.rendering_material = com_object

    @property
    def adaptive_coeff(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AdaptiveCoeff() As short
                |
                |     Returns or sets the adaptive coefficient of a material. Adaptive coefficient
                |     value is between 1 an 8.

        :rtype: int
        """
        return self.rendering_material.AdaptiveCoeff

    @adaptive_coeff.setter
    def adaptive_coeff(self, value: int):
        """
        :param int value:
        """
        min_ = 1
        max_ = 8

        if not min_ <= value <= max_:
            raise CATIAApplicationException(f"Value must be between {min_} and {max_}.")

        self.rendering_material.AdaptiveCoeff = value

    @property
    def ambient_coefficient(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AmbientCoefficient() As double
                |
                |     Returns or sets the ambient coefficient of a material. Ambient coefficient
                |     value is between 0 to 1.

        :rtype: float
        """
        return self.rendering_material.AmbientCoefficient

    @ambient_coefficient.setter
    def ambient_coefficient(self, value: float):
        """
        :param float value:
        """

        min_ = 0
        max_ = 1

        if not min_ <= value <= max_:
            raise CATIAApplicationException(f"Value must be between {min_} and {max_}.")

        self.rendering_material.AmbientCoefficient = value

    @property
    def bump(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Bump() As double
                |
                |     Returns or sets the texture bump. Image texture bump value is between -10
                |     to 10.

        :rtype: float
        """
        return self.rendering_material.Bump

    @bump.setter
    def bump(self, value: float):
        """
        :param float value:
        """

        min_ = -10
        max_ = 10

        if not min_ <= value <= max_:
            raise CATIAApplicationException(f"Value must be between {min_} and {max_}.")

        self.rendering_material.Bump = value

    @property
    def chessboard_joint_height(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ChessboardJointHeight() As double
                |
                |     Returns or sets the height of the join of a chessboard texture. Height
                |     value is between 0 to 100. N.B. Parameter use for CHESSBOARD texture type only.

        :rtype: float
        """
        return self.rendering_material.ChessboardJointHeight

    @chessboard_joint_height.setter
    def chessboard_joint_height(self, value: float):
        """
        :param float value:
        """

        min_ = 0
        max_ = 100

        if not min_ <= value <= max_:
            raise CATIAApplicationException(f"Value must be between {min_} and {max_}.")

        self.rendering_material.ChessboardJointHeight = value

    @property
    def chessboard_joint_width(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ChessboardJointWidth() As double
                |
                |     Returns or sets the width of the join of a chessboard texture. Width value
                |     is between 0 to 100. N.B. Parameter use for CHESSBOARD texture type only.

        :rtype: float
        """
        return self.rendering_material.ChessboardJointWidth

    @chessboard_joint_width.setter
    def chessboard_joint_width(self, value: float):
        """
        :param float value:
        """

        min_ = 0
        max_ = 100

        if not min_ <= value <= max_:
            raise CATIAApplicationException(f"Value must be between {min_} and {max_}.")

        self.rendering_material.ChessboardJointWidth = value

    @property
    def chessboard_offset(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ChessboardOffset() As double
                |
                |     Returns or sets the offset coefficient for a chessboard texture. It
                |     indicates the offset between each line of the chessboard texture. Offset value
                |     is between 0 to 0.5. N.B. Parameter use for CHESSBOARD texture type only.

        :rtype: float
        """

        return self.rendering_material.ChessboardOffset

    @chessboard_offset.setter
    def chessboard_offset(self, value: float):
        """
        :param float value:
        """

        min_ = 0
        max_ = 0.5

        if not min_ <= value <= max_:
            raise CATIAApplicationException(f"Value must be between {min_} and {max_}.")

        self.rendering_material.ChessboardOffset = value

    @property
    def chessboard_tile_height(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ChessboardTileHeight() As double
                |
                |     Returns or sets the height of the tile of a chessboard texture. Height
                |     value is between 0 to 100. N.B. Parameter use for CHESSBOARD texture type only.

        :rtype: float
        """

        return self.rendering_material.ChessboardTileHeight

    @chessboard_tile_height.setter
    def chessboard_tile_height(self, value: float):
        """
        :param float value:
        """

        min_ = 0
        max_ = 100

        if not min_ <= value <= max_:
            raise CATIAApplicationException(f"Value must be between {min_} and {max_}.")

        self.rendering_material.ChessboardTileHeight = value

    @property
    def chessboard_tile_width(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ChessboardTileWidth() As double
                |
                |     Returns or sets the width of the tile of a chessboard texture. Width value
                |     is between 0 to 100. N.B. Parameter use for CHESSBOARD texture type only.

        :rtype: float
        """

        return self.rendering_material.ChessboardTileWidth

    @chessboard_tile_width.setter
    def chessboard_tile_width(self, value: float):
        """
        :param float value:
        """

        min_ = 0
        max_ = 100

        if not min_ <= value <= max_:
            raise CATIAApplicationException(f"Value must be between {min_} and {max_}.")

        self.rendering_material.ChessboardTileWidth = value

    @property
    def color_number(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ColorNumber() As short
                |
                |     Returns or sets the 3d texture color number. Possible color numbers are: -
                |     From 2 to 5 for marble, vein and chessboard texture types - From 1 to 5 for
                |     alternate vein texture types N.B. Parameter useless for ROCK textures (color
                |     number is fixed) and IMAGE texture

        :rtype: int
        """

        return self.rendering_material.ColorNumber

    @color_number.setter
    def color_number(self, value: int):
        """
        :param int value:
        """

        self.rendering_material.ColorNumber = value

    @property
    def diffuse_coefficient(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DiffuseCoefficient() As double
                |
                |     Returns or sets the diffuse coefficient of a material. Diffuse coefficient
                |     value is between 0 to 1.

        :rtype: float
        """

        return self.rendering_material.DiffuseCoefficient

    @diffuse_coefficient.setter
    def diffuse_coefficient(self, value: float):
        """
        :param float value:
        """

        min_ = 0
        max_ = 1

        if not min_ <= value <= max_:
            raise CATIAApplicationException(f"Value must be between {min_} and {max_}.")

        self.rendering_material.DiffuseCoefficient = value

    @property
    def environment_image(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property EnvironmentImage() As CATBSTR
                |
                |     Returns or sets the environment image pathname of a material.

        :rtype: str
        """

        return self.rendering_material.EnvironmentImage

    @environment_image.setter
    def environment_image(self, value: str):
        """
        :param str value:
        """

        self.rendering_material.EnvironmentImage = value

    @property
    def flip_u(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FlipU() As boolean
                |
                |     Returns or sets the texture flip status along U axis. N.B. Parameter use
                |     for IMAGE texture type only

        :rtype: bool
        """

        return self.rendering_material.FlipU

    @flip_u.setter
    def flip_u(self, value: bool):
        """
        :param bool value:
        """

        self.rendering_material.FlipU = value

    @property
    def flip_v(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FlipV() As boolean
                |
                |     Returns or sets the texture flip status along V axis. N.B. Parameter use
                |     for IMAGE texture type only

        :rtype: bool
        """

        return self.rendering_material.FlipV

    @flip_v.setter
    def flip_v(self, value: bool):
        """
        :param bool value:
        """

        self.rendering_material.FlipV = value

    @property
    def mapping_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MappingType() As short
                |
                |     Returns or sets the mapping type of a material.
                |
                |         Possible types are:
                |         0: Planar mapping
                |         1: Spherical mapping
                |         2: Cylindrical mapping
                |         3: Cubical mapping
                |         4: Auto mapping
                |         5: Manual mapping

        :rtype: int
        """

        return self.rendering_material.MappingType

    @mapping_type.setter
    def mapping_type(self, value: int):
        """
        :param int value:
        """

        min_ = 0
        max_ = 5

        if not min_ <= value <= max_:
            raise CATIAApplicationException(f"Value must be between {min_} and {max_}.")

        self.rendering_material.MappingType = value

    @property
    def orientation(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Orientation() As double
                |
                |     Returns or sets the texture orientation. Orientation value should be
                |     between -360 to +360 degrees N.B. Parameter use for IMAGE texture type only

        :rtype: float
        """

        return self.rendering_material.Orientation

    @orientation.setter
    def orientation(self, value: float):
        """
        :param float value:
        """

        min_ = -360
        max_ = 360

        if not min_ <= value <= max_:
            raise CATIAApplicationException(f"Value must be between {min_} and {max_}.")

        self.rendering_material.Orientation = value

    @property
    def position_u(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PositionU() As double
                |
                |     Returns or sets the texture position along U axis. N.B. Parameter use for
                |     IMAGE texture type only

        :rtype: float
        """

        return self.rendering_material.PositionU

    @position_u.setter
    def position_u(self, value: float):
        """
        :param float value:
        """

        self.rendering_material.PositionU = value

    @property
    def position_v(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PositionV() As double
                |
                |     Returns or sets the texture position along V axis. N.B. Parameter use for
                |     IMAGE texture type only

        :rtype: float
        """

        return self.rendering_material.PositionV

    @position_v.setter
    def position_v(self, value: float):
        """
        :param float value:
        """

        self.rendering_material.PositionV = value

    @property
    def preview_size(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PreviewSize() As double
                |
                |     Returns or sets the preview size of a material. Preview size value is 0.1mm
                |     minimum.

        :rtype: float
        """

        return self.rendering_material.PreviewSize

    @preview_size.setter
    def preview_size(self, value: float):
        """
        :param float value:
        """

        self.rendering_material.PreviewSize = value

    @property
    def reflection_height(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ReflectionHeight() As double
                |
                |     Returns or sets the non-linear reflection height of a material. Non-linear
                |     reflection height value is between 0 to 1. N.B. Parameter use for CUSTOM
                |     reflection mode only.

        :rtype: float
        """

        return self.rendering_material.ReflectionHeight

    @reflection_height.setter
    def reflection_height(self, value: float):
        """
        :param float value:
        """

        min_ = 0
        max_ = 1

        if not min_ <= value <= max_:
            raise CATIAApplicationException(f"Value must be between {min_} and {max_}.")

        self.rendering_material.ReflectionHeight = value

    @property
    def reflection_length(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ReflectionLength() As double
                |
                |     Returns or sets the non-linear reflection length of a material. Non-linear
                |     reflection length value is between 0 to 1. N.B. Parameter use for CUSTOM
                |     reflection mode only.

        :rtype: float
        """

        return self.rendering_material.ReflectionLength

    @reflection_length.setter
    def reflection_length(self, value: float):
        """
        :param float value:
        """

        min_ = 0
        max_ = 1

        if not min_ <= value <= max_:
            raise CATIAApplicationException(f"Value must be between {min_} and {max_}.")

        self.rendering_material.ReflectionLength = value

    @property
    def reflection_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ReflectionMode() As short
                |
                |     Returns or sets the non-linear reflection mode of a
                |     material.
                |
                |         Possible reflection mode values are:
                |         0: CHROMA reflection mode
                |         1: PAINT reflection mode
                |         2: MATTE_METAL reflection mode
                |         3: BRIGHT_PLASTIC reflection mode
                |         4: CUSTOM reflection mode

        :rtype: int
        """

        return self.rendering_material.ReflectionMode

    @reflection_mode.setter
    def reflection_mode(self, value: int):
        """
        :param int value:
        """

        min_ = 0
        max_ = 4

        if not min_ <= value <= max_:
            raise CATIAApplicationException(f"Value must be between {min_} and {max_}.")

        self.rendering_material.ReflectionMode = value

    @property
    def reflectivity_coefficient(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ReflectivityCoefficient() As double
                |
                |     Returns or sets the reflectivity coefficient of a material. Reflectivity
                |     coefficient value is between 0 to 1.

        :rtype: float
        """

        return self.rendering_material.ReflectivityCoefficient

    @reflectivity_coefficient.setter
    def reflectivity_coefficient(self, value: float):
        """
        :param float value:
        """

        min_ = 0
        max_ = 1

        if not min_ <= value <= max_:
            raise CATIAApplicationException(f"Value must be between {min_} and {max_}.")

        self.rendering_material.ReflectivityCoefficient = value

    @property
    def refraction_coefficient(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RefractionCoefficient() As double
                |
                |     Returns or sets the refraction coefficient of a material. Refraction
                |     coefficient value is between 1 to 2.

        :rtype: float
        """

        return self.rendering_material.RefractionCoefficient

    @refraction_coefficient.setter
    def refraction_coefficient(self, value: float):
        """
        :param float value:
        """

        min_ = 1
        max_ = 2

        if not min_ <= value <= max_:
            raise CATIAApplicationException(f"Value must be between {min_} and {max_}.")

        self.rendering_material.RefractionCoefficient = value

    @property
    def repeat_u(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RepeatU() As boolean
                |
                |     Returns or sets the texture repeat status along U axis. N.B. Parameter use
                |     for IMAGE texture type only

        :rtype: bool
        """

        return self.rendering_material.RepeatU

    @repeat_u.setter
    def repeat_u(self, value: bool):
        """
        :param bool value:
        """

        self.rendering_material.RepeatU = value

    @property
    def repeat_v(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RepeatV() As boolean
                |
                |     Returns or sets the texture repeat status along V axis. N.B. Parameter use
                |     for IMAGE texture type only

        :rtype: bool
        """

        return self.rendering_material.RepeatV

    @repeat_v.setter
    def repeat_v(self, value: bool):
        """
        :param bool value:
        """

        self.rendering_material.RepeatV = value

    @property
    def scale_u(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ScaleU() As double
                |
                |     Returns or sets the texture scale along U axis. U scale value is between 0
                |     to 100. N.B. Parameter use for IMAGE texture type only

        :rtype: float
        """

        return self.rendering_material.ScaleU

    @scale_u.setter
    def scale_u(self, value: float):
        """
        :param float value:
        """

        min_ = 0
        max_ = 100

        if not min_ <= value <= max_:
            raise CATIAApplicationException(f"Value must be between {min_} and {max_}.")

        self.rendering_material.ScaleU = value

    @property
    def scale_v(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ScaleV() As double
                |
                |     Returns or sets the texture scale along V axis. V scale value is between 0
                |     to 100. N.B. Parameter use for IMAGE texture type only

        :rtype: float
        """

        return self.rendering_material.ScaleV

    @scale_v.setter
    def scale_v(self, value: float):
        """
        :param float value:
        """

        min_ = 0
        max_ = 100

        if not min_ <= value <= max_:
            raise CATIAApplicationException(f"Value must be between {min_} and {max_}.")

        self.rendering_material.ScaleV = value

    @property
    def specular_coefficient(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SpecularCoefficient() As double
                |
                |     Returns or sets the specular coefficient of a material. Specular
                |     coefficient value is between 0 to 1.

        :rtype: float
        """

        return self.rendering_material.SpecularCoefficient

    @specular_coefficient.setter
    def specular_coefficient(self, value: float):
        """
        :param float value:
        """

        min_ = 0
        max_ = 1

        if not min_ <= value <= max_:
            raise CATIAApplicationException(f"Value must be between {min_} and {max_}.")

        self.rendering_material.SpecularCoefficient = value

    @property
    def specular_exponent(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SpecularExponent() As double
                |
                |     Returns or sets the specular exponent of a material. Specular exponent
                |     value is between 0 to 1.

        :rtype: float
        """

        return self.rendering_material.SpecularExponent

    @specular_exponent.setter
    def specular_exponent(self, value: float):
        """
        :param float value:
        """

        min_ = 0
        max_ = 1

        if not min_ <= value <= max_:
            raise CATIAApplicationException(f"Value must be between {min_} and {max_}.")

        self.rendering_material.SpecularExponent = value

    @property
    def texture_amplitude(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TextureAmplitude() As double
                |
                |     Returns or sets the 3d texture amplitude coefficient. Amplitude value is
                |     between 0 to 1. N.B. Parameter use for MARBLE and ROCK texture type only.

        :rtype: float
        """

        return self.rendering_material.TextureAmplitude

    @texture_amplitude.setter
    def texture_amplitude(self, value: float):
        """
        :param float value:
        """

        min_ = 0
        max_ = 1

        if not min_ <= value <= max_:
            raise CATIAApplicationException(f"Value must be between {min_} and {max_}.")

        self.rendering_material.TextureAmplitude = value

    @property
    def texture_complexity(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TextureComplexity() As short
                |
                |     Returns or sets the 3d texture complexity. Complexity value is between 0 to
                |     10. N.B. Parameter use for MARBLE and ROCK texture types only.

        :rtype: int
        """

        return self.rendering_material.TextureComplexity

    @texture_complexity.setter
    def texture_complexity(self, value: int):
        """
        :param int value:
        """

        min_ = 0
        max_ = 10

        if not min_ <= value <= max_:
            raise CATIAApplicationException(f"Value must be between {min_} and {max_}.")

        self.rendering_material.TextureComplexity = value

    @property
    def texture_gain(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TextureGain() As double
                |
                |     Returns or sets the 3d texture gain coefficient. Gain value is between 0 to
                |     2. N.B. Parameter use for ROCK texture type only.

        :rtype: float
        """

        return self.rendering_material.TextureGain

    @texture_gain.setter
    def texture_gain(self, value: float):
        """
        :param float value:
        """

        min_ = 0
        max_ = 2

        if not min_ <= value <= max_:
            raise CATIAApplicationException(f"Value must be between {min_} and {max_}.")

        self.rendering_material.TextureGain = value

    @property
    def texture_image(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TextureImage() As CATBSTR
                |
                |     Returns or sets the texture image pathname of a material. N.B. Parameter
                |     use for IMAGE texture type only

        :rtype: str
        """

        return self.rendering_material.TextureImage

    @texture_image.setter
    def texture_image(self, value: str):
        """
        :param str value:
        """

        self.rendering_material.TextureImage = value

    @property
    def texture_perturbation(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TexturePerturbation() As double
                |
                |     Returns or sets the 3d texture perturbation coefficient. Perturbation value
                |     is between 1 to 10. N.B. Parameter use for VEIN, ALTERNATE VEIN and ROCK
                |     texture types only.

        :rtype: float
        """

        return self.rendering_material.TexturePerturbation

    @texture_perturbation.setter
    def texture_perturbation(self, value: float):
        """
        :param float value:
        """

        min_ = 10
        max_ = 10

        if not min_ <= value <= max_:
            raise CATIAApplicationException(f"Value must be between {min_} and {max_}.")

        self.rendering_material.TexturePerturbation = value

    @property
    def texture_turbulence(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TextureTurbulence() As boolean
                |
                |     Returns or sets the 3d texture turbulence status. N.B. Parameter use for
                |     ROCK texture type only.

        :rtype: bool
        """

        return self.rendering_material.TextureTurbulence

    @texture_turbulence.setter
    def texture_turbulence(self, value: bool):
        """
        :param bool value:
        """

        self.rendering_material.TextureTurbulence = value

    @property
    def texture_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TextureType() As short
                |
                |     Returns or sets the texture type of a material. The possible values for
                |     this type can be:
                |
                |         Possible reflection mode values are:
                |         0: NO texture
                |         1: IMAGE texture
                |         2: MARBLE texture
                |         3: VEIN texture
                |         4: ALTERNATE VEIN texture
                |         5: ROCK texture
                |         6: CHESSBOARD texture

        :rtype: int
        """

        return self.rendering_material.TextureType

    @texture_type.setter
    def texture_type(self, value: int):
        """
        :param int value:
        """

        min_ = 0
        max_ = 6

        if not min_ <= value <= max_:
            raise CATIAApplicationException(f"Value must be between {min_} and {max_}.")

        self.rendering_material.TextureType = value

    @property
    def texture_vein_amplitude(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TextureVeinAmplitude() As double
                |
                |     Returns or sets the 3d texture vein amplitude coefficient. Amplitude value
                |     is between 0 to 10. N.B. Parameter use for VEIN and ALTERNATE VEIN texture
                |     types only.

        :rtype: float
        """

        return self.rendering_material.TextureVeinAmplitude

    @texture_vein_amplitude.setter
    def texture_vein_amplitude(self, value: float):
        """
        :param float value:
        """

        min_ = 0
        max_ = 10

        if not min_ <= value <= max_:
            raise CATIAApplicationException(f"Value must be between {min_} and {max_}.")

        self.rendering_material.TextureVeinAmplitude = value

    @property
    def transparency_coefficient(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TransparencyCoefficient() As double
                |
                |     Returns or sets the transparency coefficient of a material. Transparency
                |     coefficient value is between 0 to 1.

        :rtype: float
        """

        return self.rendering_material.TransparencyCoefficient

    @transparency_coefficient.setter
    def transparency_coefficient(self, value: float):
        """
        :param float value:
        """

        min_ = 0
        max_ = 1

        if not min_ <= value <= max_:
            raise CATIAApplicationException(f"Value must be between {min_} and {max_}.")

        self.rendering_material.TransparencyCoefficient = value

    def get_3d_texture_color(self, i_color_index: int) -> tuple[int, int, int]:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Get3DTextureColor(short iColorIndex,
                | CATSafeArrayVariant o3DTextureColor)
                |
                |     Returns one color of a 3d texture. The color to access is identified with
                |     its index. The color is expressed with r, g, and b coefficients (between 0 and
                |     255).
                |
                |     Parameters:
                |
                |         iColorIndex
                |             The index of the color to access
                |
                |     Returns:
                |         the color as a safe array made up of three doubles: r, g,
                |         b
                |         The r, g, b values ranges from 0 to 255.
                |         The array must be previously initialized. N.B. Parameter useless for
                |         image textures.

        :param int i_color_index:
        :rtype: tuple
        """
        vba_function_name = "get_3d_texture_color"
        vba_code = f"""
        Public Function {vba_function_name}(comObject, iColorIndex)
            Dim o3DTextureColor(3) As CATSafeArrayVariant
            comObject.Get3DTextureColor iColorIndex, o3DTextureColor
            {vba_function_name} = o3DTextureColor
        End Function
        """
        value = self.application.system_service.evaluate(
            vba_code, 0, vba_function_name, [self.com_object, i_color_index]
        )
        return int(value[0]), int(value[1]), int(value[2])

    def get_3d_texture_color_coefficient(self, i_color_index: int) -> tuple[int, int, int]:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Get3DTextureColorCoefficient(short iColorIndex,
                | double o3DTextureColorCoefficient)
                |
                |     Returns one color coefficient of a 3d texture. The color to access is
                |     identified with its index.
                |
                |     Parameters:
                |
                |         iColorIndex
                |             The index of the color to access.
                |
                |     Returns:
                |         the color coefficient.
                |         If the color is enable, the color coefficient value should range from 0
                |         to 1.
                |         If color is disable, the color coefficient is equal to
                |         -1.
                |         N.B. Parameter useless for rock, chessboard and image textures.

        :param int i_color_index:
        :rtype: tuple
        """
        vba_function_name = "get_3d_texture_color_coefficient"
        vba_code = f"""
        Public Function {vba_function_name}(comObject, iColorIndex)
            Dim o3DTextureColorCoefficient(3) As CATSafeArrayVariant
            comObject.Get3DTextureColorCoefficient iColorIndex, o3DTextureColorCoefficient
            {vba_function_name} = o3DTextureColorCoefficient
        End Function
        """
        value = self.application.system_service.evaluate(
            vba_code, 0, vba_function_name, [self.com_object, i_color_index]
        )
        return int(value[0]), int(value[1]), int(value[2])

    def get_3d_texture_orientation(self) -> tuple[float, float, float]:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Get3DTextureOrientation(CATSafeArrayVariant
                | o3DTextureOrientation)
                |
                |     Returns the orientation of a texture. The orientation is expressed with 3
                |     coefficients (orientation around X, Y and Z axis). The orientation values must
                |     be between -360 and 360 degrees. N.B. Parameter useless for IMAGE textures (use
                |     get_Orientation, set_Orientation methods for IMAGE type).
                |
                |     Returns:
                |         the orientation as a safe array made up of three doubles: rotationX,
                |         rotationY, rotationZ.
                |         The array must be previously initialized.

        :rtype: tuple
        """
        vba_function_name = "get_3d_texture_orientation"
        vba_code = f"""
        Public Function {vba_function_name}(comObject)
            Dim o3DTextureOrientation(3) As CATSafeArrayVariant
            comObject.Get3DTextureOrientation o3DTextureOrientation
            {vba_function_name} = o3DTextureOrientation
        End Function
        """
        value = self.application.system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
        return value[0], value[1], value[2]

    def get_3d_texture_position(self) -> tuple[float, float, float]:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Get3DTexturePosition(CATSafeArrayVariant
                | o3DTexturePosition)
                |
                |     Returns the position of a texture. The position is expressed with 3
                |     coefficients (position along X, Y and Z axis). The position values must be
                |     between -100 and 100. N.B. Parameter useless for IMAGE textures (use PositionU,
                |     PositionV methods for IMAGE type).
                |
                |     Returns:
                |         the position as a safe array made up of three doubles: positionX,
                |         positionY, positionZ.
                |         The array must be previously initialized.

        :rtype: tuple
        """
        vba_function_name = "get_3d_texture_position"
        vba_code = f"""
        Public Function {vba_function_name}(comObject)
            Dim o3DTexturePosition(3) As CATSafeArrayVariant
            comObject.Get3DTexturePosition o3DTexturePosition
            {vba_function_name} = o3DTexturePosition
        End Function
        """
        value = self.application.system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
        return value[0], value[1], value[2]

    def get_3d_texture_scale(self) -> tuple[int, int, int]:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Get3DTextureScale(CATSafeArrayVariant o3DTextureScale)
                |
                |     Returns the scale of a texture. The scale is expressed with 3 coefficients
                |     (scale along X, Y and Z axis) The scale values must be > 0 and ≤ 100. N.B.
                |     Parameter useless for IMAGE textures. (use get_ScaleU, set_ScaleU, get_ScaleV,
                |     set_ScaleV methods for IMAGE type)
                |
                |     Returns:
                |         the scale as a safe array made up of three doubles: scaleX, scaleY,
                |         scaleZ.
                |         The array must be previously initialized.

        :rtype: tuple
        """
        vba_function_name = "get_3d_texture_scale"
        vba_code = f"""
        Public Function {vba_function_name}(comObject)
            Dim o3DTextureScale(3) As CATSafeArrayVariant
            comObject.Get3DTextureScale o3DTextureScale
            {vba_function_name} = o3DTextureScale
        End Function
        """
        value = self.application.system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
        return int(value[0]), int(value[1]), int(value[2])

    def get_ambient_color(self) -> tuple[int, int, int]:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAmbientColor(CATSafeArrayVariant oAmbientColor)
                |
                |     Returns the ambient color of a material. The color is expressed with r, g,
                |     and b coefficients (between 0 and 255)
                |
                |     Returns:
                |         the color as a safe array made up of three doubles: r, g,
                |         b
                |         The r, g, b values ranges from 0 to 255.
                |         The array must be previously initialized.

        :rtype: tuple
        """
        vba_function_name = "get_ambient_color"
        vba_code = f"""
        Public Function {vba_function_name}(comObject)
            Dim oAmbientColor(3) As CATSafeArrayVariant
            comObject.GetAmbientColor oAmbientColor
            {vba_function_name} = oAmbientColor
        End Function
        """
        value = self.application.system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
        return int(value[0]), int(value[1]), int(value[2])

    def get_diffuse_color(self) -> tuple[int, int, int]:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetDiffuseColor(CATSafeArrayVariant oDiffuseColor)
                |
                |     Returns the diffuse color of a material. The color is expressed with r, g,
                |     and b coefficients (between 0 and 255)
                |
                |     Returns:
                |         the color as a safe array made up of three doubles: r, g,
                |         b
                |         The r, g, b values ranges from 0 to 255.
                |         The array must be previously initialized.

        :rtype: tuple
        """
        vba_function_name = "get_diffuse_color"
        vba_code = f"""
        Public Function {vba_function_name}(comObject)
            Dim oDiffuseColor(3) As CATSafeArrayVariant
            comObject.GetDiffuseColor oDiffuseColor
            {vba_function_name} = oDiffuseColor
        End Function
        """
        value = self.application.system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
        return int(value[0]), int(value[1]), int(value[2])

    def get_specular_color(self) -> tuple[int, int, int]:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetSpecularColor(CATSafeArrayVariant oSpecularColor)
                |
                |     Returns the specular color of a material. The color is expressed with r, g,
                |     and b coefficients (between 0 and 255)
                |
                |     Returns:
                |         the color as a safe array made up of three doubles: r, g,
                |         b
                |         The r, g, b values ranges from 0 to 255.
                |         The array must be previously initialized.

        :rtype: tuple
        """
        vba_function_name = "get_specular_color"
        vba_code = f"""
        Public Function {vba_function_name}(comObject)
            Dim oSpecularColor(3) As CATSafeArrayVariant
            comObject.GetSpecularColor oSpecularColor
            {vba_function_name} = oSpecularColor
        End Function
        """
        value = self.application.system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
        return int(value[0]), int(value[1]), int(value[2])

    def get_transparency_color(self) -> tuple[int, int, int]:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetTransparencyColor(CATSafeArrayVariant
                | oTransparencyColor)
                |
                |     Returns the transparent color of a material. The color is expressed with r,
                |     g, and b coefficients (between 0 and 255)
                |
                |     Parameters:
                |
                |         oTransparencyColor
                |             The color as a safe array made up of three doubles: r, g,
                |             b
                |             The r, g, b values ranges from 0 to 255.
                |             The array must be previously initialized.

        :rtype: tuple
        """
        vba_function_name = "get_transparency_color"
        vba_code = f"""
        Public Function {vba_function_name}(comObject)
            Dim oTransparencyColor(3) As CATSafeArrayVariant
            comObject.GetTransparencyColor oTransparencyColor
            {vba_function_name} = oTransparencyColor
        End Function
        """
        value = self.application.system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
        return int(value[0]), int(value[1]), int(value[2])

    def put_3d_texture_color(self, i_color_index: int, i_3d_texture_color: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Put3DTextureColor(short iColorIndex,
                | CATSafeArrayVariant i3DTextureColor)
                |
                |     Sets one color of a 3d texture. The color to access is identified with its
                |     index. The color is expressed with r, g, and b coefficients (between 0 and
                |     255)
                |
                |     Parameters:
                |
                |         iColorIndex
                |             The index of the color to access.
                |         i3DTextureColor
                |             The color as a safe array made up of three doubles: r, g,
                |             b
                |             The r, g, b values ranges from 0 to 255.
                |             The array must be previously initialized. N.B. Parameter useless
                |             for image textures.

        :param int i_color_index:
        :param tuple i_3d_texture_color:
        :rtype: None
        """
        return self.rendering_material.Put3DTextureColor(i_color_index, i_3d_texture_color)

    def put_3d_texture_color_coefficient(self, i_color_index: int, i_3d_texture_color_coefficient: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Put3DTextureColorCoefficient(short iColorIndex,
                | double i3DTextureColorCoefficient)
                |
                |     Sets one color coefficient of a 3d texture. The color to access is
                |     identified with its index.
                |
                |     Parameters:
                |
                |         iColorIndex
                |             The index of the color to access.
                |         i3DTextureColorCoefficient.
                |             The color coefficient.
                |             If color is enable, the color coefficient value should range from 0
                |             to 1.
                |             If color is disable, the color coefficient should be equal to
                |             -1.
                |             N.B. Parameter useless for rock, chessboard and image
                |             textures.

        :param int i_color_index:
        :param float i_3d_texture_color_coefficient:
        :rtype: None
        """
        return self.rendering_material.Put3DTextureColorCoefficient(i_color_index, i_3d_texture_color_coefficient)

    def put_3d_texture_orientation(self, i_3d_texture_orientation: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Put3DTextureOrientation(CATSafeArrayVariant
                | i3DTextureOrientation)
                |
                |     Sets the orientation of a texture. The orientation is expressed with 3
                |     coefficients (orientation around X, Y and Z axis). The orientation values must
                |     be between -360 and 360 degrees. N.B. Parameter useless for IMAGE textures (use
                |     get_Orientation, set_Orientation methods for IMAGE type).
                |
                |     Parameters:
                |
                |         i3DTextureOrientation
                |             The orientation as a safe array made up of three doubles:
                |             rotationX, rotationY, rotationZ.
                |             The array must be previously initialized.

        :param tuple i_3d_texture_orientation:
        :rtype: None
        """
        return self.rendering_material.Put3DTextureOrientation(i_3d_texture_orientation)

    def put_3d_texture_position(self, i_3d_texture_position: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Put3DTexturePosition(CATSafeArrayVariant
                | i3DTexturePosition)
                |
                |     Sets the position of a texture. The position is expressed with 3
                |     coefficients (position along X, Y and Z axis). The position values must be
                |     between -100 and 100. N.B. Parameter useless for IMAGE textures (use PositionU,
                |     PositionV methods for IMAGE type).
                |
                |     Parameters:
                |
                |         i3DTexturePosition
                |             The position as a safe array made up of three doubles: positionX,
                |             positionY, positionZ.
                |             The array must be previously initialized.

        :param tuple i_3d_texture_position:
        :rtype: None
        """
        return self.rendering_material.Put3DTexturePosition(i_3d_texture_position)

    def put_3d_texture_scale(self, i_3d_texture_scale: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Put3DTextureScale(CATSafeArrayVariant i3DTextureScale)
                |
                |     Sets the scale of a texture. The scale is expressed with 3 coefficients
                |     (scale along X, Y and Z axis). The scale values must be > 0 and ≤ 100. N.B.
                |     Parameter useless for IMAGE textures (use get_ScaleU, set_ScaleU, get_ScaleV,
                |     set_ScaleV methods for IMAGE type).
                |
                |     Parameters:
                |
                |         i3DTextureScale
                |             The scale as a safe array made up of three doubles: scaleX, scaleY,
                |             scaleZ.
                |             The array must be previously initialized.

        :param tuple i_3d_texture_scale:
        :rtype: None
        """
        return self.rendering_material.Put3DTextureScale(i_3d_texture_scale)

    def put_ambient_color(self, i_ambient_color: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub PutAmbientColor(CATSafeArrayVariant iAmbientColor)
                |
                |     Sets the ambient color of a material. The color is expressed with r, g, and
                |     b coefficients (between 0 and 255)
                |
                |     Parameters:
                |
                |         oAmbientColor
                |             The color as a safe array made up of three doubles: r, g,
                |             b
                |             The r, g, b values ranges from 0 to 255.
                |             The array must be previously initialized.

        :param tuple i_ambient_color:
        :rtype: None
        """
        return self.rendering_material.PutAmbientColor(i_ambient_color)

    def put_diffuse_color(self, i_diffuse_color: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub PutDiffuseColor(CATSafeArrayVariant iDiffuseColor)
                |
                |     Sets the diffuse color of a material. The color is expressed with r, g, and
                |     b coefficients (between 0 and 255)
                |
                |     Parameters:
                |
                |         oDiffuseColor
                |             The color as a safe array made up of three doubles: r, g,
                |             b
                |             The r, g, b values ranges from 0 to 255.
                |             The array must be previously initialized.

        :param tuple i_diffuse_color:
        :rtype: None
        """
        return self.rendering_material.PutDiffuseColor(i_diffuse_color)

    def put_specular_color(self, i_specular_color: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub PutSpecularColor(CATSafeArrayVariant iSpecularColor)
                |
                |     Sets the specular color of a material. The color is expressed with r, g,
                |     and b coefficients (between 0 and 255)
                |
                |     Parameters:
                |
                |         oSpecularColor
                |             The color as a safe array made up of three doubles: r, g,
                |             b
                |             The r, g, b values ranges from 0 to 255.
                |             The array must be previously initialized.

        :param tuple i_specular_color:
        :rtype: None
        """
        return self.rendering_material.PutSpecularColor(i_specular_color)

    def put_transparency_color(self, i_transparency_color: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub PutTransparencyColor(CATSafeArrayVariant
                | iTransparencyColor)
                |
                |     Sets the transparent color of a material. The color is expressed with r, g,
                |     and b coefficients (between 0 and 255)
                |
                |     Parameters:
                |
                |         iTransparencyColor
                |             The color as a safe array made up of three doubles: r, g,
                |             b
                |             The r, g, b values ranges from 0 to 255.
                |             The array must be previously initialized.

        :param tuple i_transparency_color:
        :rtype: None
        """
        return self.rendering_material.PutTransparencyColor(i_transparency_color)

    def __repr__(self):
        return f'RenderingMaterial(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_property import ABQProperty


class ABQThermalConnBehavior(ABQProperty):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAutomationItf.ABQProperty
                |                         ABQThermalConnBehavior
                | 
                | Represents an Abaqus thermal connection behavior (ABQThermalConnBehavior)
                | object.
                | Role: Access an Abaqus thermal connection behaviour object or determine its
                | properties.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_thermal_conn_behavior = com_object

    @property
    def conductance_table_size(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ConductanceTableSize() As long (Read Only)
                | 
                |     Returns the size of the conductance table.
                | 
                |     Returns:
                |         The size of the conductance table.

        :rtype: int
        """

        return self.abq_thermal_conn_behavior.ConductanceTableSize

    @property
    def description(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Description() As CATBSTR
                | 
                |     Sets or returns the description.
                | 
                |     Returns:
                |         The description of the step.

        :rtype: str
        """

        return self.abq_thermal_conn_behavior.Description

    @description.setter
    def description(self, value: str):
        """
        :param str value:
        """

        self.abq_thermal_conn_behavior.Description = value

    @property
    def temperature_dependency(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property temperatureDependency() As boolean
                | 
                |     Sets or returns the temperature dependency.
                | 
                |     Returns:
                |         A boolean specifying whether the values are dependent on temperature.

        :rtype: bool
        """

        return self.abq_thermal_conn_behavior.temperatureDependency

    @temperature_dependency.setter
    def temperature_dependency(self, value: bool):
        """
        :param bool value:
        """

        self.abq_thermal_conn_behavior.temperatureDependency = value

    def add_gap_conduction_table(self, i_conductance: tuple, i_clearance: tuple, i_temperature: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddGapConductionTable(CATSafeArrayVariant
                | iConductance,
                | CATSafeArrayVariant iClearance,
                | CATSafeArrayVariant iTemperature)
                | 
                |     Adds a gap-conductance table using three lists containing gap, conductance,
                |     and temperature values. Temperature list will be ignored if the temperature
                |     dependency is OFF. The number of values in all of the parameter lists must
                |     match. If either list contains extra values, the extra values are
                |     discarded.
                | 
                |     Parameters:
                | 
                |         iConductance
                |             The list of conductance values (in W/degK/m^2).
                |         iClearance
                |             The list of clearance values (in meter).
                |         iTemperature
                |             The list of temperature values (in degK).

        :param tuple i_conductance:
        :param tuple i_clearance:
        :param tuple i_temperature:
        :rtype: None
        """
        return self.abq_thermal_conn_behavior.AddGapConductionTable(i_conductance, i_clearance, i_temperature)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_gap_conduction_table'
        # # vba_code = """
        # # Public Function add_gap_conduction_table(abq_thermal_conn_behavior)
        # #     Dim iConductance (2)
        # #     abq_thermal_conn_behavior.AddGapConductionTable iConductance
        # #     add_gap_conduction_table = iConductance
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_gap_conduction_table(self, o_conductance: tuple, o_clearance: tuple, o_temperature: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetGapConductionTable(CATSafeArrayVariant
                | oConductance,
                | CATSafeArrayVariant oClearance,
                | CATSafeArrayVariant oTemperature)
                | 
                |     Returns list(s) containing gap, conductance, and temperature
                |     values.
                | 
                |     Returns:
                |         The lists of gap, conductance, and temperature values. The list of
                |         temperature values will be ignored if the temperature dependency is OFF.
                |         
                |     Parameters:
                | 
                |         oConductance
                |             The list of conductance values (in W/degK/m^2).
                |         oClearance
                |             The list of clearance values (in mm).
                |         oTemperature
                |             The list of temperature values (in degK).

        :param tuple o_conductance:
        :param tuple o_clearance:
        :param tuple o_temperature:
        :rtype: None
        """
        return self.abq_thermal_conn_behavior.GetGapConductionTable(o_conductance, o_clearance, o_temperature)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_gap_conduction_table'
        # # vba_code = """
        # # Public Function get_gap_conduction_table(abq_thermal_conn_behavior)
        # #     Dim oConductance (2)
        # #     abq_thermal_conn_behavior.GetGapConductionTable oConductance
        # #     get_gap_conduction_table = oConductance
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ABQThermalConnBehavior(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class SWKLineOfSightNode(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SWKLineOfSightNode
                | 
                | This interface characterizes a node.
                | 
                | A node is a convenient way to regroup different attributes of the
                | manikin.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.swk_line_of_sight_node = com_object

    def lock_posture(self, pi_dof_id: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub LockPosture(long piDOFId)
                | 
                |     Lock the posture of the line of sight for the dof piDOFId.

        :param int pi_dof_id:
        :rtype: None
        """
        return self.swk_line_of_sight_node.LockPosture(pi_dof_id)

    def optimize(self, pi_dof_id: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Optimize(long piDOFId)
                | 
                |     Sets the limits to match the best PrefAngle for the DOF piDOFId

        :param int pi_dof_id:
        :rtype: None
        """
        return self.swk_line_of_sight_node.Optimize(pi_dof_id)

    def reset_angular_limitations(self, pi_dof_id: int, pi_reset: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ResetAngularLimitations(long piDOFId,
                | long piReset)
                | 
                |     Reset the angular limitations of the line of sight depending on piReset: 0
                |     -> 2 OR 3 OR 4 depending of the first encountered. 1 -> 2 AND 3 AND 4 2 ->
                |     Unlock the value 3 -> Restore the angular limitations if it is "No Limits" 4 ->
                |     Set back the angular limitations to their default value (50.0%)

        :param int pi_dof_id:
        :param int pi_reset:
        :rtype: None
        """
        return self.swk_line_of_sight_node.ResetAngularLimitations(pi_dof_id, pi_reset)

    def reset_posture(self, pi_dof_id: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ResetPosture(long piDOFId)
                | 
                |     Reset the posture of the line of sight for the dof piDOFId.

        :param int pi_dof_id:
        :rtype: None
        """
        return self.swk_line_of_sight_node.ResetPosture(pi_dof_id)

    def reset_pref_angles(self, pi_dof_id: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ResetPrefAngles(long piDOFId)
                | 
                |     Reset the preferred angles of the line of sight for the dof piDOFId.

        :param int pi_dof_id:
        :rtype: None
        """
        return self.swk_line_of_sight_node.ResetPrefAngles(pi_dof_id)

    def set_percentage(self, pi_percentage: float, pi_dof_id: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPercentage(double piPercentage,
                | long piDOFId)
                | 
                |     Sets the angular limitations to a percentage for the DOF piDOFId

        :param float pi_percentage:
        :param int pi_dof_id:
        :rtype: None
        """
        return self.swk_line_of_sight_node.SetPercentage(pi_percentage, pi_dof_id)

    def __repr__(self):
        return f'SWKLineOfSightNode(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.parameter import Parameter
from pycatia.system_interfaces.any_object import AnyObject


class ManufacturingMachine(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ManufacturingMachine
                | 
                | Machine in machining domain.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_machine = com_object

    @property
    def comment(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Comment() As CATBSTR (Read Only)
                | 
                |     Return the Comment of a Machine.
                | 
                |     Example:
                |         The following example return the comment MachineComment of to the
                |         manufacturing Machine CurrentMachine
                | 
                |          MachineComment = CurrentMachine.Comment

        :rtype: str
        """

        return self.manufacturing_machine.Comment

    @property
    def machine_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MachineType() As CATBSTR (Read Only)
                | 
                |     Return the Type of a Machine.
                | 
                |     Example:
                |         The following example return the type MachineType of to the
                |         manufacturing Machine CurrentMachine
                | 
                |          MachineType = CurrentMachine.Type

        :rtype: str
        """

        return self.manufacturing_machine.MachineType

    @property
    def number_of_attributes(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NumberOfAttributes() As short (Read Only)
                | 
                |     Gives the number of attributes of a ManufacturingMachine.
                | 
                |     Example:
                |         The following example returns the Number of attributes of the
                |         ManufacturingMachine CurrentMachine
                | 
                |          Number = CurrentMachine.NumberOfAttributes

        :rtype: int
        """

        return self.manufacturing_machine.NumberOfAttributes

    @property
    def number_of_numerical_control_attributes(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NumberOfNumericalControlAttributes() As short (Read
                | Only)
                | 
                |     This property returns the number of Numerical Control attributes of a
                |     Manufacturing Machine.

        :rtype: int
        """

        return self.manufacturing_machine.NumberOfNumericalControlAttributes

    @property
    def number_of_rotary_table_attributes(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NumberOfRotaryTableAttributes() As short (Read
                | Only)
                | 
                |     This property returns the number of rotary table attributes of a
                |     Manufacturing Machine. The machine is upposed to accept Rotary table (type is
                |     Mfg3AxisWithTableRotationMachine).

        :rtype: int
        """

        return self.manufacturing_machine.NumberOfRotaryTableAttributes

    @property
    def number_of_spindle_attributes(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NumberOfSpindleAttributes() As short (Read Only)
                | 
                |     This property returns the number of Spindle attributes of a Manufacturing
                |     Machine.

        :rtype: int
        """

        return self.manufacturing_machine.NumberOfSpindleAttributes

    @property
    def number_of_tool_change_attributes(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NumberOfToolChangeAttributes() As short (Read
                | Only)
                | 
                |     This property returns the number of Tool change attributes of a
                |     Manufacturing Machine.

        :rtype: int
        """

        return self.manufacturing_machine.NumberOfToolChangeAttributes

    @property
    def pp_table_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PPTableName() As CATBSTR
                | 
                |     Give the PPTableName linked to a Manufacturing Machine.
                | 
                |     Example:
                |         The following example returns the PPTableName ThisPPTable linked to the
                |         Manufacturing Machine CurrentMachine
                | 
                |          Set ThisPPTable = CurrentMachine.PPTableName

        :rtype: str
        """

        return self.manufacturing_machine.PPTableName

    @pp_table_name.setter
    def pp_table_name(self, value: str):
        """
        :param str value:
        """

        self.manufacturing_machine.PPTableName = value

    @property
    def post_processor_file(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PostProcessorFile() As CATBSTR
                | 
                |     This property returns the post processor file of a Manufacturing Machine
                |     Machine.PostProcessorFile

        :rtype: str
        """

        return self.manufacturing_machine.PostProcessorFile

    @post_processor_file.setter
    def post_processor_file(self, value: str):
        """
        :param str value:
        """

        self.manufacturing_machine.PostProcessorFile = value

    @property
    def preferred_tool_catalog_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PreferedToolCatalogName() As CATBSTR
                | 
                |     Give the PreferedToolCatalogName linked to a Manufacturing
                |     Machine.
                | 
                |     Example:
                |         The following example returns the PreferedToolCatalogName ThisCatalog
                |         linked to the Manufacturing Machine CurrentMachine
                | 
                |          Set ThisCatalog = CurrentMachine.PreferedToolCatalogName

        :rtype: str
        """

        return self.manufacturing_machine.PreferedToolCatalogName

    @preferred_tool_catalog_name.setter
    def preferred_tool_catalog_name(self, value: str):
        """
        :param str value:
        """

        self.manufacturing_machine.PreferedToolCatalogName = value

    @property
    def rotary_axis(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RotaryAxis() As CATBSTR
                | 
                |     Give the MfgRotaryAxis linked to a Manufacturing Machine.
                | 
                |     Example:
                |         The following example returns the MfgRotaryAxis ThisAxis linked to the
                |         Manufacturing Machine CurrentMachine
                | 
                |          Set ThisAxis = CurrentMachine.RotaryAxis

        :rtype: str
        """

        return self.manufacturing_machine.RotaryAxis

    @rotary_axis.setter
    def rotary_axis(self, value: str):
        """
        :param str value:
        """

        self.manufacturing_machine.RotaryAxis = value

    def default_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func DefaultName() As CATBSTR
                | 
                |     Return the string the Type of a Machine.
                | 
                |     Example:
                |         The following example return the type MachineType of to the
                |         manufacturing Machine CurrentMachine
                | 
                |          MachineType = CurrentMachine.Type

        :rtype: str
        """
        return self.manufacturing_machine.DefaultName()

    def get_attribute(self, i_attribute: str) -> Parameter:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttribute(CATBSTR iAttribut) As Parameter
                | 
                |     Retrieve the Attribute of a Manufacturing Machine.
                | 
                |     Example:
                |         The following example retreives in HomePosX the attribute
                |         MFG_HOME_POS_X of Manufacturing Machine MyMachine
                | 
                |           Set HomePosX = MyMachine.GetAttribute(MFG_HOME_POS_X)

        :param str i_attribute:
        :rtype: Parameter
        """
        return Parameter(self.manufacturing_machine.GetAttribute(i_attribute))

    def get_attribute_nls_name(self, i_attribute_name: str) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttributeNLSName(CATBSTR iAttributName) As CATBSTR
                | 
                |     Retrieve the NLS name from the attribute name of a Manufacturing
                |     Machine.

        :param str i_attribute_name:
        :rtype: str
        """
        return self.manufacturing_machine.GetAttributeNLSName(i_attribute_name)

    def get_list_of_attribute_units(self, o_list_of_attribute_units: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetListOfAttributeUnits(CATSafeArrayVariant
                | oListOfAttributeUnits)
                | 
                |     Retrieve the list of attribute units of a
                |     ManufacturingMachine.
                |     The number of items in the output array is equal to the number of
                |     attributes of the machine.
                |     When an attribute has no unit definition, the corresponding unit item in
                |     the output array is a blank string.
                | 
                |     Example:
                |         The following example retrieves in TabAttributeUnits the list of
                |         attribute units of the ManufacturingMachine
                |         CurrentMachine
                | 
                |          call CurrentMachine.GetListOfAttributeUnits(TabAttributeUnits)

        :param tuple o_list_of_attribute_units:
        :rtype: None
        """
        return self.manufacturing_machine.GetListOfAttributeUnits(o_list_of_attribute_units)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_list_of_attribute_units'
        # # vba_code = """
        # # Public Function get_list_of_attribute_units(manufacturing_machine)
        # #     Dim oListOfAttributeUnits (2)
        # #     manufacturing_machine.GetListOfAttributeUnits oListOfAttributeUnits
        # #     get_list_of_attribute_units = oListOfAttributeUnits
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_list_of_attributes(self, o_list_of_attributes: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetListOfAttributes(CATSafeArrayVariant
                | oListOfAttributes)
                | 
                |     Retrieve the list of all attributes of a
                |     ManufacturingMachine.
                |     Each attribute is returned as the name of a CKE object.
                | 
                |     Example:
                |         The following example retrieves in TabAttributes the list of attributes
                |         of the ManufacturingMachine CurrentMachine
                | 
                |          call
                |          CurrentMachine.GetListOfAttributes(TabAttributes)

        :param tuple o_list_of_attributes:
        :rtype: None
        """
        return self.manufacturing_machine.GetListOfAttributes(o_list_of_attributes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_list_of_attributes'
        # # vba_code = """
        # # Public Function get_list_of_attributes(manufacturing_machine)
        # #     Dim oListOfAttributes (2)
        # #     manufacturing_machine.GetListOfAttributes oListOfAttributes
        # #     get_list_of_attributes = oListOfAttributes
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_list_of_numerical_control_attributes(self, o_list_of_attributes: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetListOfNumericalControlAttributes(CATSafeArrayVariant
                | oListOfAttributes)
                | 
                |     Retrieve the list of Numerical Control attributes of a Manufacturing
                |     Machine.
                |     Each attribute is returned as the name of a CKE object.
                | 
                |     Example:
                |         The following example retrieves in oListOfAttributes the list of
                |         Numerical Control attributes of the Manufacturing Machine
                |         myMachine
                | 
                |          call myMachine.GetListOfNumericalControlAttributes(oListOfAttributes)

        :param tuple o_list_of_attributes:
        :rtype: None
        """
        return self.manufacturing_machine.GetListOfNumericalControlAttributes(o_list_of_attributes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_list_of_numerical_control_attributes'
        # # vba_code = """
        # # Public Function get_list_of_numerical_control_attributes(manufacturing_machine)
        # #     Dim oListOfAttributes (2)
        # #     manufacturing_machine.GetListOfNumericalControlAttributes oListOfAttributes
        # #     get_list_of_numerical_control_attributes = oListOfAttributes
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_list_of_rotary_table_attributes(self, o_list_of_attributes: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetListOfRotaryTableAttributes(CATSafeArrayVariant
                | oListOfAttributes)
                | 
                |     Retrieve the list of Rotary table attributes of a Manufacturing
                |     Machine.
                |     Each attribute is returned as the name of a CKE object.
                | 
                |     Example:
                |         The following example retrieves in oListOfAttributes the list of Tool
                |         Change attributes of the Manufacturing Machine
                |         myMachine
                | 
                |          call myMachine.GetListOfRotaryTableAttributes(oListOfAttributes)

        :param tuple o_list_of_attributes:
        :rtype: None
        """
        return self.manufacturing_machine.GetListOfRotaryTableAttributes(o_list_of_attributes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_list_of_rotary_table_attributes'
        # # vba_code = """
        # # Public Function get_list_of_rotary_table_attributes(manufacturing_machine)
        # #     Dim oListOfAttributes (2)
        # #     manufacturing_machine.GetListOfRotaryTableAttributes oListOfAttributes
        # #     get_list_of_rotary_table_attributes = oListOfAttributes
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_list_of_spindle_attributes(self, o_list_of_attributes: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetListOfSpindleAttributes(CATSafeArrayVariant
                | oListOfAttributes)
                | 
                |     Retrieve the list of Spindle attributes of a Manufacturing
                |     Machine.
                |     Each attribute is returned as the name of a CKE object.
                | 
                |     Example:
                |         The following example retrieves in oListOfAttributes the list of
                |         Spindle attributes of the Manufacturing Machine
                |         myMachine
                | 
                |          call myMachine.GetListOfSpindleAttributes(oListOfAttributes)

        :param tuple o_list_of_attributes:
        :rtype: None
        """
        return self.manufacturing_machine.GetListOfSpindleAttributes(o_list_of_attributes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_list_of_spindle_attributes'
        # # vba_code = """
        # # Public Function get_list_of_spindle_attributes(manufacturing_machine)
        # #     Dim oListOfAttributes (2)
        # #     manufacturing_machine.GetListOfSpindleAttributes oListOfAttributes
        # #     get_list_of_spindle_attributes = oListOfAttributes
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_list_of_tool_change_attributes(self, o_list_of_attributes: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetListOfToolChangeAttributes(CATSafeArrayVariant
                | oListOfAttributes)
                | 
                |     Retrieve the list of Tool Change attributes of a Manufacturing
                |     Machine.
                |     Each attribute is returned as the name of a CKE object.
                | 
                |     Example:
                |         The following example retrieves in oListOfAttributes the list of Tool
                |         Change attributes of the Manufacturing Machine
                |         myMachine
                | 
                |          call myMachine.GetListOfToolChangeAttributes(oListOfAttributes)

        :param tuple o_list_of_attributes:
        :rtype: None
        """
        return self.manufacturing_machine.GetListOfToolChangeAttributes(o_list_of_attributes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_list_of_tool_change_attributes'
        # # vba_code = """
        # # Public Function get_list_of_tool_change_attributes(manufacturing_machine)
        # #     Dim oListOfAttributes (2)
        # #     manufacturing_machine.GetListOfToolChangeAttributes oListOfAttributes
        # #     get_list_of_tool_change_attributes = oListOfAttributes
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_default_values(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_DefaultValues()
                | 
                |     Initialise the Manufacturing Machine parameters.
                | 
                |     Example:
                |         The following example make the init of the parameter of the Machine
                |         ThisMachine .
                | 
                |          call ThisMachine.set_DefaultValues

        :rtype: None
        """
        return self.manufacturing_machine.set_DefaultValues()

    def __repr__(self):
        return f'ManufacturingMachine(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.analysis_interfaces.analysis_case import AnalysisCase
from pycatia.analysis_interfaces.analysis_manager import AnalysisManager
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject


class AnalysisImport(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     AnalysisImport
                | 
                | The interface to access a CATIAAnalysisExport
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.analysis_import = com_object

    def add_support(self, i_manager: AnalysisManager, i_product_support: Product, i_support: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupport(AnalysisManager iManager,
                | Product iProductSupport,
                | AnyObject iSupport)
                | 
                |     AddSupport for loads import if needed.
                |     )
                | 
                |     Parameters:
                | 
                |         iManager
                |             The Analysis manager.
                |             ) 
                |         iProductSupport
                |             Product of the geometrical support.
                |             ) 
                |         iSupports
                |             Geometrical support.
                |             )

        :param AnalysisManager i_manager:
        :param Product i_product_support:
        :param AnyObject i_support:
        :rtype: None
        """
        return self.analysis_import.AddSupport(i_manager.com_object, i_product_support.com_object, i_support.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support'
        # # vba_code = """
        # # Public Function add_support(analysis_import)
        # #     Dim iManager (2)
        # #     analysis_import.AddSupport iManager
        # #     add_support = iManager
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def import_disp(self, i_father_case: AnalysisCase, i_full_path: str, i_manager: AnalysisManager,
                    i_axis: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ImportDisp(AnalysisCase iFatherCase,
                | CATBSTR iFullPath,
                | AnalysisManager iManager,
                | AnyObject iAxis)
                | 
                |     Import displacements from a CATAnalysisExport file.
                |     )
                | 
                |     Parameters:
                | 
                |         iFatherCase
                |             case where Displacements will be exported.
                |             ) 
                |         iFullPath
                |             The full path of the file.
                |             ) 
                |         iManager
                |             analysis manager where the disp is exported.
                |             ) 
                |         iAxis
                |             The user axis system to be taken into account.
                |             )

        :param AnalysisCase i_father_case:
        :param str i_full_path:
        :param AnalysisManager i_manager:
        :param AnyObject i_axis:
        :rtype: None
        """
        return self.analysis_import.ImportDisp(i_father_case.com_object, i_full_path, i_manager.com_object,
                                               i_axis.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'import_disp'
        # # vba_code = """
        # # Public Function import_disp(analysis_import)
        # #     Dim iFatherCase (2)
        # #     analysis_import.ImportDisp iFatherCase
        # #     import_disp = iFatherCase
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def import_force(self, i_father_case: AnalysisCase, i_full_path: str, i_manager: AnalysisManager,
                     i_axis: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ImportForce(AnalysisCase iFatherCase,
                | CATBSTR iFullPath,
                | AnalysisManager iManager,
                | AnyObject iAxis)
                | 
                |     Import loads from a CATAnalysisExport file.
                |     )
                | 
                |     Parameters:
                | 
                |         iFatherCase
                |             case where loads will be exported.
                |             ) 
                |         iFullPath
                |             The full path of the file.
                |             ) 
                |         iManager
                |             analysis manager where the disp is exported.
                |             ) 
                |         iAxis
                |             The user axis system to be taken into account.
                |             )

        :param AnalysisCase i_father_case:
        :param str i_full_path:
        :param AnalysisManager i_manager:
        :param AnyObject i_axis:
        :rtype: None
        """
        return self.analysis_import.ImportForce(i_father_case.com_object, i_full_path, i_manager.com_object,
                                                i_axis.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'import_force'
        # # vba_code = """
        # # Public Function import_force(analysis_import)
        # #     Dim iFatherCase (2)
        # #     analysis_import.ImportForce iFatherCase
        # #     import_force = iFatherCase
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'AnalysisImport(name="{self.name}")'
